Class: Aws::MigrationHubOrchestrator::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MigrationHubOrchestrator::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-migrationhuborchestrator/client.rb,
sig/client.rbs
Overview
An API client for MigrationHubOrchestrator. To construct a client, you need to configure a :region and :credentials.
client = Aws::MigrationHubOrchestrator::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateTemplateResponseSuccess, _CreateWorkflowResponseSuccess, _CreateWorkflowStepGroupResponseSuccess, _CreateWorkflowStepResponseSuccess, _DeleteTemplateResponseSuccess, _DeleteWorkflowResponseSuccess, _DeleteWorkflowStepGroupResponseSuccess, _DeleteWorkflowStepResponseSuccess, _GetTemplateResponseSuccess, _GetTemplateStepGroupResponseSuccess, _GetTemplateStepResponseSuccess, _GetWorkflowResponseSuccess, _GetWorkflowStepGroupResponseSuccess, _GetWorkflowStepResponseSuccess, _ListPluginsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTemplateStepGroupsResponseSuccess, _ListTemplateStepsResponseSuccess, _ListTemplatesResponseSuccess, _ListWorkflowStepGroupsResponseSuccess, _ListWorkflowStepsResponseSuccess, _ListWorkflowsResponseSuccess, _RetryWorkflowStepResponseSuccess, _StartWorkflowResponseSuccess, _StopWorkflowResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateTemplateResponseSuccess, _UpdateWorkflowResponseSuccess, _UpdateWorkflowStepGroupResponseSuccess, _UpdateWorkflowStepResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_template(params = {}) ⇒ Types::CreateTemplateResponse
Creates a migration workflow template.
-
#create_workflow(params = {}) ⇒ Types::CreateMigrationWorkflowResponse
Create a workflow to orchestrate your migrations.
-
#create_workflow_step(params = {}) ⇒ Types::CreateWorkflowStepResponse
Create a step in the migration workflow.
-
#create_workflow_step_group(params = {}) ⇒ Types::CreateWorkflowStepGroupResponse
Create a step group in a migration workflow.
-
#delete_template(params = {}) ⇒ Struct
Deletes a migration workflow template.
-
#delete_workflow(params = {}) ⇒ Types::DeleteMigrationWorkflowResponse
Delete a migration workflow.
-
#delete_workflow_step(params = {}) ⇒ Struct
Delete a step in a migration workflow.
-
#delete_workflow_step_group(params = {}) ⇒ Struct
Delete a step group in a migration workflow.
-
#get_template(params = {}) ⇒ Types::GetMigrationWorkflowTemplateResponse
Get the template you want to use for creating a migration workflow.
-
#get_template_step(params = {}) ⇒ Types::GetTemplateStepResponse
Get a specific step in a template.
-
#get_template_step_group(params = {}) ⇒ Types::GetTemplateStepGroupResponse
Get a step group in a template.
-
#get_workflow(params = {}) ⇒ Types::GetMigrationWorkflowResponse
Get migration workflow.
-
#get_workflow_step(params = {}) ⇒ Types::GetWorkflowStepResponse
Get a step in the migration workflow.
-
#get_workflow_step_group(params = {}) ⇒ Types::GetWorkflowStepGroupResponse
Get the step group of a migration workflow.
-
#list_plugins(params = {}) ⇒ Types::ListPluginsResponse
List AWS Migration Hub Orchestrator plugins.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List the tags added to a resource.
-
#list_template_step_groups(params = {}) ⇒ Types::ListTemplateStepGroupsResponse
List the step groups in a template.
-
#list_template_steps(params = {}) ⇒ Types::ListTemplateStepsResponse
List the steps in a template.
-
#list_templates(params = {}) ⇒ Types::ListMigrationWorkflowTemplatesResponse
List the templates available in Migration Hub Orchestrator to create a migration workflow.
-
#list_workflow_step_groups(params = {}) ⇒ Types::ListWorkflowStepGroupsResponse
List the step groups in a migration workflow.
-
#list_workflow_steps(params = {}) ⇒ Types::ListWorkflowStepsResponse
List the steps in a workflow.
-
#list_workflows(params = {}) ⇒ Types::ListMigrationWorkflowsResponse
List the migration workflows.
-
#retry_workflow_step(params = {}) ⇒ Types::RetryWorkflowStepResponse
Retry a failed step in a migration workflow.
-
#start_workflow(params = {}) ⇒ Types::StartMigrationWorkflowResponse
Start a migration workflow.
-
#stop_workflow(params = {}) ⇒ Types::StopMigrationWorkflowResponse
Stop an ongoing migration workflow.
-
#tag_resource(params = {}) ⇒ Struct
Tag a resource by specifying its Amazon Resource Name (ARN).
-
#untag_resource(params = {}) ⇒ Struct
Deletes the tags for a resource.
-
#update_template(params = {}) ⇒ Types::UpdateTemplateResponse
Updates a migration workflow template.
-
#update_workflow(params = {}) ⇒ Types::UpdateMigrationWorkflowResponse
Update a migration workflow.
-
#update_workflow_step(params = {}) ⇒ Types::UpdateWorkflowStepResponse
Update a step in a migration workflow.
-
#update_workflow_step_group(params = {}) ⇒ Types::UpdateWorkflowStepGroupResponse
Update the step group in a migration workflow.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2192 2193 2194 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 2192 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2195 2196 2197 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 2195 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 2165 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MigrationHubOrchestrator') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-migrationhuborchestrator' context[:gem_version] = '1.50.0' Seahorse::Client::Request.new(handlers, context) end |
#create_template(params = {}) ⇒ Types::CreateTemplateResponse
Creates a migration workflow template.
88 |
# File 'sig/client.rbs', line 88 def create_template: ( |
#create_workflow(params = {}) ⇒ Types::CreateMigrationWorkflowResponse
Create a workflow to orchestrate your migrations.
114 |
# File 'sig/client.rbs', line 114 def create_workflow: ( |
#create_workflow_step(params = {}) ⇒ Types::CreateWorkflowStepResponse
Create a step in the migration workflow.
138 |
# File 'sig/client.rbs', line 138 def create_workflow_step: ( |
#create_workflow_step_group(params = {}) ⇒ Types::CreateWorkflowStepGroupResponse
Create a step group in a migration workflow.
166 |
# File 'sig/client.rbs', line 166 def create_workflow_step_group: ( |
#delete_template(params = {}) ⇒ Struct
Deletes a migration workflow template.
179 |
# File 'sig/client.rbs', line 179 def delete_template: ( |
#delete_workflow(params = {}) ⇒ Types::DeleteMigrationWorkflowResponse
Delete a migration workflow. You must pause a running workflow in Migration Hub Orchestrator console to delete it.
191 |
# File 'sig/client.rbs', line 191 def delete_workflow: ( |
#delete_workflow_step(params = {}) ⇒ Struct
Delete a step in a migration workflow. Pause the workflow to delete a running step.
200 |
# File 'sig/client.rbs', line 200 def delete_workflow_step: ( |
#delete_workflow_step_group(params = {}) ⇒ Struct
Delete a step group in a migration workflow.
211 |
# File 'sig/client.rbs', line 211 def delete_workflow_step_group: ( |
#get_template(params = {}) ⇒ Types::GetMigrationWorkflowTemplateResponse
Get the template you want to use for creating a migration workflow.
233 |
# File 'sig/client.rbs', line 233 def get_template: ( |
#get_template_step(params = {}) ⇒ Types::GetTemplateStepResponse
Get a specific step in a template.
253 |
# File 'sig/client.rbs', line 253 def get_template_step: ( |
#get_template_step_group(params = {}) ⇒ Types::GetTemplateStepGroupResponse
Get a step group in a template.
274 |
# File 'sig/client.rbs', line 274 def get_template_step_group: ( |
#get_workflow(params = {}) ⇒ Types::GetMigrationWorkflowResponse
Get migration workflow.
304 |
# File 'sig/client.rbs', line 304 def get_workflow: ( |
#get_workflow_step(params = {}) ⇒ Types::GetWorkflowStepResponse
Get a step in the migration workflow.
334 |
# File 'sig/client.rbs', line 334 def get_workflow_step: ( |
#get_workflow_step_group(params = {}) ⇒ Types::GetWorkflowStepGroupResponse
Get the step group of a migration workflow.
357 |
# File 'sig/client.rbs', line 357 def get_workflow_step_group: ( |
#list_plugins(params = {}) ⇒ Types::ListPluginsResponse
List AWS Migration Hub Orchestrator plugins.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
369 |
# File 'sig/client.rbs', line 369 def list_plugins: ( |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List the tags added to a resource.
380 |
# File 'sig/client.rbs', line 380 def list_tags_for_resource: ( |
#list_template_step_groups(params = {}) ⇒ Types::ListTemplateStepGroupsResponse
List the step groups in a template.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
391 |
# File 'sig/client.rbs', line 391 def list_template_step_groups: ( |
#list_template_steps(params = {}) ⇒ Types::ListTemplateStepsResponse
List the steps in a template.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
404 |
# File 'sig/client.rbs', line 404 def list_template_steps: ( |
#list_templates(params = {}) ⇒ Types::ListMigrationWorkflowTemplatesResponse
List the templates available in Migration Hub Orchestrator to create a migration workflow.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
418 |
# File 'sig/client.rbs', line 418 def list_templates: ( |
#list_workflow_step_groups(params = {}) ⇒ Types::ListWorkflowStepGroupsResponse
List the step groups in a migration workflow.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
431 |
# File 'sig/client.rbs', line 431 def list_workflow_step_groups: ( |
#list_workflow_steps(params = {}) ⇒ Types::ListWorkflowStepsResponse
List the steps in a workflow.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
444 |
# File 'sig/client.rbs', line 444 def list_workflow_steps: ( |
#list_workflows(params = {}) ⇒ Types::ListMigrationWorkflowsResponse
List the migration workflows.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
458 |
# File 'sig/client.rbs', line 458 def list_workflows: ( |
#retry_workflow_step(params = {}) ⇒ Types::RetryWorkflowStepResponse
Retry a failed step in a migration workflow.
476 |
# File 'sig/client.rbs', line 476 def retry_workflow_step: ( |
#start_workflow(params = {}) ⇒ Types::StartMigrationWorkflowResponse
Start a migration workflow.
492 |
# File 'sig/client.rbs', line 492 def start_workflow: ( |
#stop_workflow(params = {}) ⇒ Types::StopMigrationWorkflowResponse
Stop an ongoing migration workflow.
506 |
# File 'sig/client.rbs', line 506 def stop_workflow: ( |
#tag_resource(params = {}) ⇒ Struct
Tag a resource by specifying its Amazon Resource Name (ARN).
515 |
# File 'sig/client.rbs', line 515 def tag_resource: ( |
#untag_resource(params = {}) ⇒ Struct
Deletes the tags for a resource.
525 |
# File 'sig/client.rbs', line 525 def untag_resource: ( |
#update_template(params = {}) ⇒ Types::UpdateTemplateResponse
Updates a migration workflow template.
538 |
# File 'sig/client.rbs', line 538 def update_template: ( |
#update_workflow(params = {}) ⇒ Types::UpdateMigrationWorkflowResponse
Update a migration workflow.
562 |
# File 'sig/client.rbs', line 562 def update_workflow: ( |
#update_workflow_step(params = {}) ⇒ Types::UpdateWorkflowStepResponse
Update a step in a migration workflow.
584 |
# File 'sig/client.rbs', line 584 def update_workflow_step: ( |
#update_workflow_step_group(params = {}) ⇒ Types::UpdateWorkflowStepGroupResponse
Update the step group in a migration workflow.
614 |
# File 'sig/client.rbs', line 614 def update_workflow_step_group: ( |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2185 2186 2187 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 2185 def waiter_names [] end |