Class: Aws::MigrationHubOrchestrator::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MigrationHubOrchestrator::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-migrationhuborchestrator/client.rb
Overview
An API client for MigrationHubOrchestrator. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::MigrationHubOrchestrator::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_template(params = {}) ⇒ Types::CreateTemplateResponse
Creates a migration workflow template.
-
#create_workflow(params = {}) ⇒ Types::CreateMigrationWorkflowResponse
Create a workflow to orchestrate your migrations.
-
#create_workflow_step(params = {}) ⇒ Types::CreateWorkflowStepResponse
Create a step in the migration workflow.
-
#create_workflow_step_group(params = {}) ⇒ Types::CreateWorkflowStepGroupResponse
Create a step group in a migration workflow.
-
#delete_template(params = {}) ⇒ Struct
Deletes a migration workflow template.
-
#delete_workflow(params = {}) ⇒ Types::DeleteMigrationWorkflowResponse
Delete a migration workflow.
-
#delete_workflow_step(params = {}) ⇒ Struct
Delete a step in a migration workflow.
-
#delete_workflow_step_group(params = {}) ⇒ Struct
Delete a step group in a migration workflow.
-
#get_template(params = {}) ⇒ Types::GetMigrationWorkflowTemplateResponse
Get the template you want to use for creating a migration workflow.
-
#get_template_step(params = {}) ⇒ Types::GetTemplateStepResponse
Get a specific step in a template.
-
#get_template_step_group(params = {}) ⇒ Types::GetTemplateStepGroupResponse
Get a step group in a template.
-
#get_workflow(params = {}) ⇒ Types::GetMigrationWorkflowResponse
Get migration workflow.
-
#get_workflow_step(params = {}) ⇒ Types::GetWorkflowStepResponse
Get a step in the migration workflow.
-
#get_workflow_step_group(params = {}) ⇒ Types::GetWorkflowStepGroupResponse
Get the step group of a migration workflow.
-
#list_plugins(params = {}) ⇒ Types::ListPluginsResponse
List AWS Migration Hub Orchestrator plugins.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List the tags added to a resource.
-
#list_template_step_groups(params = {}) ⇒ Types::ListTemplateStepGroupsResponse
List the step groups in a template.
-
#list_template_steps(params = {}) ⇒ Types::ListTemplateStepsResponse
List the steps in a template.
-
#list_templates(params = {}) ⇒ Types::ListMigrationWorkflowTemplatesResponse
List the templates available in Migration Hub Orchestrator to create a migration workflow.
-
#list_workflow_step_groups(params = {}) ⇒ Types::ListWorkflowStepGroupsResponse
List the step groups in a migration workflow.
-
#list_workflow_steps(params = {}) ⇒ Types::ListWorkflowStepsResponse
List the steps in a workflow.
-
#list_workflows(params = {}) ⇒ Types::ListMigrationWorkflowsResponse
List the migration workflows.
-
#retry_workflow_step(params = {}) ⇒ Types::RetryWorkflowStepResponse
Retry a failed step in a migration workflow.
-
#start_workflow(params = {}) ⇒ Types::StartMigrationWorkflowResponse
Start a migration workflow.
-
#stop_workflow(params = {}) ⇒ Types::StopMigrationWorkflowResponse
Stop an ongoing migration workflow.
-
#tag_resource(params = {}) ⇒ Struct
Tag a resource by specifying its Amazon Resource Name (ARN).
-
#untag_resource(params = {}) ⇒ Struct
Deletes the tags for a resource.
-
#update_template(params = {}) ⇒ Types::UpdateTemplateResponse
Updates a migration workflow template.
-
#update_workflow(params = {}) ⇒ Types::UpdateMigrationWorkflowResponse
Update a migration workflow.
-
#update_workflow_step(params = {}) ⇒ Types::UpdateWorkflowStepResponse
Update a step in a migration workflow.
-
#update_workflow_step_group(params = {}) ⇒ Types::UpdateWorkflowStepGroupResponse
Update the step group in a migration workflow.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2192 2193 2194 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 2192 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2195 2196 2197 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 2195 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 2165 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MigrationHubOrchestrator') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-migrationhuborchestrator' context[:gem_version] = '1.47.0' Seahorse::Client::Request.new(handlers, context) end |
#create_template(params = {}) ⇒ Types::CreateTemplateResponse
Creates a migration workflow template.
534 535 536 537 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 534 def create_template(params = {}, = {}) req = build_request(:create_template, params) req.send_request() end |
#create_workflow(params = {}) ⇒ Types::CreateMigrationWorkflowResponse
Create a workflow to orchestrate your migrations.
626 627 628 629 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 626 def create_workflow(params = {}, = {}) req = build_request(:create_workflow, params) req.send_request() end |
#create_workflow_step(params = {}) ⇒ Types::CreateWorkflowStepResponse
Create a step in the migration workflow.
721 722 723 724 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 721 def create_workflow_step(params = {}, = {}) req = build_request(:create_workflow_step, params) req.send_request() end |
#create_workflow_step_group(params = {}) ⇒ Types::CreateWorkflowStepGroupResponse
Create a step group in a migration workflow.
783 784 785 786 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 783 def create_workflow_step_group(params = {}, = {}) req = build_request(:create_workflow_step_group, params) req.send_request() end |
#delete_template(params = {}) ⇒ Struct
Deletes a migration workflow template.
805 806 807 808 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 805 def delete_template(params = {}, = {}) req = build_request(:delete_template, params) req.send_request() end |
#delete_workflow(params = {}) ⇒ Types::DeleteMigrationWorkflowResponse
Delete a migration workflow. You must pause a running workflow in Migration Hub Orchestrator console to delete it.
838 839 840 841 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 838 def delete_workflow(params = {}, = {}) req = build_request(:delete_workflow, params) req.send_request() end |
#delete_workflow_step(params = {}) ⇒ Struct
Delete a step in a migration workflow. Pause the workflow to delete a running step.
869 870 871 872 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 869 def delete_workflow_step(params = {}, = {}) req = build_request(:delete_workflow_step, params) req.send_request() end |
#delete_workflow_step_group(params = {}) ⇒ Struct
Delete a step group in a migration workflow.
895 896 897 898 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 895 def delete_workflow_step_group(params = {}, = {}) req = build_request(:delete_workflow_step_group, params) req.send_request() end |
#get_template(params = {}) ⇒ Types::GetMigrationWorkflowTemplateResponse
Get the template you want to use for creating a migration workflow.
951 952 953 954 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 951 def get_template(params = {}, = {}) req = build_request(:get_template, params) req.send_request() end |
#get_template_step(params = {}) ⇒ Types::GetTemplateStepResponse
Get a specific step in a template.
1018 1019 1020 1021 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1018 def get_template_step(params = {}, = {}) req = build_request(:get_template_step, params) req.send_request() end |
#get_template_step_group(params = {}) ⇒ Types::GetTemplateStepGroupResponse
Get a step group in a template.
1072 1073 1074 1075 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1072 def get_template_step_group(params = {}, = {}) req = build_request(:get_template_step_group, params) req.send_request() end |
#get_workflow(params = {}) ⇒ Types::GetMigrationWorkflowResponse
Get migration workflow.
1147 1148 1149 1150 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1147 def get_workflow(params = {}, = {}) req = build_request(:get_workflow, params) req.send_request() end |
#get_workflow_step(params = {}) ⇒ Types::GetWorkflowStepResponse
Get a step in the migration workflow.
1239 1240 1241 1242 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1239 def get_workflow_step(params = {}, = {}) req = build_request(:get_workflow_step, params) req.send_request() end |
#get_workflow_step_group(params = {}) ⇒ Types::GetWorkflowStepGroupResponse
Get the step group of a migration workflow.
1297 1298 1299 1300 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1297 def get_workflow_step_group(params = {}, = {}) req = build_request(:get_workflow_step_group, params) req.send_request() end |
#list_plugins(params = {}) ⇒ Types::ListPluginsResponse
List AWS Migration Hub Orchestrator plugins.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1339 1340 1341 1342 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1339 def list_plugins(params = {}, = {}) req = build_request(:list_plugins, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List the tags added to a resource.
1368 1369 1370 1371 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1368 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_template_step_groups(params = {}) ⇒ Types::ListTemplateStepGroupsResponse
List the step groups in a template.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1414 1415 1416 1417 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1414 def list_template_step_groups(params = {}, = {}) req = build_request(:list_template_step_groups, params) req.send_request() end |
#list_template_steps(params = {}) ⇒ Types::ListTemplateStepsResponse
List the steps in a template.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1469 1470 1471 1472 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1469 def list_template_steps(params = {}, = {}) req = build_request(:list_template_steps, params) req.send_request() end |
#list_templates(params = {}) ⇒ Types::ListMigrationWorkflowTemplatesResponse
List the templates available in Migration Hub Orchestrator to create a migration workflow.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1514 1515 1516 1517 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1514 def list_templates(params = {}, = {}) req = build_request(:list_templates, params) req.send_request() end |
#list_workflow_step_groups(params = {}) ⇒ Types::ListWorkflowStepGroupsResponse
List the step groups in a migration workflow.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1562 1563 1564 1565 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1562 def list_workflow_step_groups(params = {}, = {}) req = build_request(:list_workflow_step_groups, params) req.send_request() end |
#list_workflow_steps(params = {}) ⇒ Types::ListWorkflowStepsResponse
List the steps in a workflow.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1621 1622 1623 1624 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1621 def list_workflow_steps(params = {}, = {}) req = build_request(:list_workflow_steps, params) req.send_request() end |
#list_workflows(params = {}) ⇒ Types::ListMigrationWorkflowsResponse
List the migration workflows.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1684 1685 1686 1687 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1684 def list_workflows(params = {}, = {}) req = build_request(:list_workflows, params) req.send_request() end |
#retry_workflow_step(params = {}) ⇒ Types::RetryWorkflowStepResponse
Retry a failed step in a migration workflow.
1726 1727 1728 1729 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1726 def retry_workflow_step(params = {}, = {}) req = build_request(:retry_workflow_step, params) req.send_request() end |
#start_workflow(params = {}) ⇒ Types::StartMigrationWorkflowResponse
Start a migration workflow.
1762 1763 1764 1765 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1762 def start_workflow(params = {}, = {}) req = build_request(:start_workflow, params) req.send_request() end |
#stop_workflow(params = {}) ⇒ Types::StopMigrationWorkflowResponse
Stop an ongoing migration workflow.
1798 1799 1800 1801 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1798 def stop_workflow(params = {}, = {}) req = build_request(:stop_workflow, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tag a resource by specifying its Amazon Resource Name (ARN).
1828 1829 1830 1831 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1828 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Deletes the tags for a resource.
1855 1856 1857 1858 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1855 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_template(params = {}) ⇒ Types::UpdateTemplateResponse
Updates a migration workflow template.
1904 1905 1906 1907 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1904 def update_template(params = {}, = {}) req = build_request(:update_template, params) req.send_request() end |
#update_workflow(params = {}) ⇒ Types::UpdateMigrationWorkflowResponse
Update a migration workflow.
1987 1988 1989 1990 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 1987 def update_workflow(params = {}, = {}) req = build_request(:update_workflow, params) req.send_request() end |
#update_workflow_step(params = {}) ⇒ Types::UpdateWorkflowStepResponse
Update a step in a migration workflow.
2090 2091 2092 2093 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 2090 def update_workflow_step(params = {}, = {}) req = build_request(:update_workflow_step, params) req.send_request() end |
#update_workflow_step_group(params = {}) ⇒ Types::UpdateWorkflowStepGroupResponse
Update the step group in a migration workflow.
2156 2157 2158 2159 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 2156 def update_workflow_step_group(params = {}, = {}) req = build_request(:update_workflow_step_group, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2185 2186 2187 |
# File 'lib/aws-sdk-migrationhuborchestrator/client.rb', line 2185 def waiter_names [] end |